@@ -185,6 +185,15 @@ The following classes provided by this portion building a solid fundament to imp
 * :class:`UserPreferencesTour`
 
 
+app tour start and stop events
+------------------------------
+
+The following main app event methods get called (if they exist) in relation to the start/stop of an app tour:
+
+* `on_tour_init`: called when an app tour got initialized and is just before to be started.
+* `on_tour_exit`: called when an app tour got finished and the app states got restored to the values of the tour start.
+
+
 UI-specific implementation
 --------------------------
 
@@ -206,7 +215,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.2.36'
+__version__ = '0.2.37'
 
 
 register_package_translations()
@@ -517,6 +526,8 @@ class TourBase:
 
         self.backup_app_states()
 
+        main_app.call_method('on_tour_init', self)  # notify main app to backup additional app-specific non-app-states
+
     def backup_app_states(self):
         """ backup current states of this app, including flow. """
         main_app = self.main_app
@@ -610,13 +621,8 @@ class TourBase:
             delay, self.prev_page if self.auto_switch_pages < 0 else self.next_page)
 
     def reset_app_flow(self):
-        """ delayed reset of flow path/id to be processed after dispatch of popups dismiss. """
+        """ delayed reset of flow path/id to be processed on tour start and after dispatching of popups dismiss. """
         self.main_app.vpo("TourBase.reset_app_flow")
-        # optionally set/overwrite current app flow, e.g. like:
-        # main_app = self.main_app
-        # main_app.change_app_state('flow_id', '')
-        # main_app.change_app_state('flow_path', list())
-        # main_app.refresh_all()
 
     def reset_app_states(self):
         """ reset app to a defined start to prepare a new tour start. """
@@ -724,6 +730,8 @@ class TourBase:
         """ stop/cancel tour. """
         self.main_app.vpo("TourBase.stop")
         self.teardown_app_flow()
+        # notify main app to restore additional app-specific states (delayed to be called after self.reset_app_flow())
+        self.main_app.call_method_delayed(self.page_data.get('app_reset_delay', 0.3) + 0.12, 'on_tour_exit', self)
 
     def teardown_app_flow(self):
         """ restore app flow and app states before tour finishing or before preparing/switching to prev/next page. """
@@ -925,7 +933,7 @@ class HelpAppBase(MainAppBase, ABC):
 
         :param help_vars:       locals (args/kwargs) of overwritten :meth:`~ae.gui_app.MainAppBase.change_flow` method.
 
-                                items passed to the help text formater:
+                                items passed to the help text formatter:
                                     * `count`: optional number used to render a pluralized help text
                                       for this app state change.
 
@@ -955,7 +963,7 @@ class HelpAppBase(MainAppBase, ABC):
 
         :param help_id:         help id to show help text for.
         :param help_vars:       variables used in the conversion of the f-string expression to a string.
-                                optional items passed to the help text formater:
+                                optional items passed to the help text formatter:
                                 * `count`: optional number used to render a pluralized help text.
                                 * `self`: target widget to show help text for.
         :param key_suffix:      suffix to the key used if the translation is a dict.
@@ -984,7 +992,7 @@ class HelpAppBase(MainAppBase, ABC):
 
         self.ensure_top_most_z_index(hlw)
         self.change_observable('displayed_help_id', help_id)
-        self.call_method('on_help_displayed')
+        self.call_method_delayed(0.12, 'on_help_displayed')
 
         return True
 
@@ -1101,6 +1109,11 @@ class HelpAppBase(MainAppBase, ABC):
             self.help_display('', dict())
         return True
 
+    def on_help_displayed(self):
+        """ default post help display event handler for to update the window pos of the explained widget. """
+        hlw = self.help_layout
+        hlw.explained_pos = hlw.explained_widget.to_window(*hlw.explained_widget.pos)
+
     def save_app_states(self) -> str:
         """ override MainAppBase method to not overwrite app states if app tour is active. """
         if self.tour_layout:
@@ -1127,7 +1140,7 @@ class HelpAppBase(MainAppBase, ABC):
         """" determine all visible and tourable children widgets of the passed parent and its child container widgets.
 
         :param parent_widget:   parent widget to determine all children that are tourable.
-        :return:                list of tourable children of the passed parent widget.
+        :return:                list of page ids of tourable children of the passed parent widget.
         """
         tourable_children = list()
         for wid in self.widget_children(parent_widget, only_visible=True):
